==> scpred-cli-0.0.8-0.tar.bz2: bin/scpred_get_std_output.R <==
#!/usr/bin/env Rscript
suppressPackageStartupMessages(require(optparse))
suppressPackageStartupMessages(require(workflowscriptscommon))

### create final workflow output in standard format
option_list = list(
    make_option(
        c("-i", "--predictions-file"),
        action = 'store',
        default = NA,
        type = 'character',
        help = 'Path to the predictions file in text format'
    ),
    make_option(
        c("-b", "--cell-id-col"),
        action = 'store',
        default = NA,
        type = 'character',
        help = 'Cell id column name. If not provided, it is assumed cell ids are represented by index'
    ),
    make_option(
        c("-s", "--get-scores"),
        action = 'store_true',
        default = FALSE,
        type = 'logical',
        help = 'Should score column be added? Default: FALSE'
    ),
    make_option(
        c("-k", "--classifier"),
        action = 'store',
        default = NA,
        type = 'character',
        help = 'Path to the classifier object in .rds format (Optional; required to add dataset of origin to output table)'
    ),
    make_option(
        c("-o", "--output-table"),
        action = 'store',
        default = NA,
        type = 'character',
        help = 'Path to the final output file in text format'
    )
)

opt = wsc_parse_args(option_list, mandatory = c("predictions_file", "output_table"))
data = read.csv(opt$predictions_file, row.names = 1)
if(!is.na(opt$cell_id_col)){
    barcodes = as.character(data[, opt$cell_id_col])
    } else{
        barcodes = row.names(data)
    }

output = cbind(cell_id=barcodes, pred_label=as.character(data[, "predClass"]))
if(opt$get_scores){
    # exclude label column
    scores = data[,-ncol(data)]
    .get_max = function(vec){
        vec = as.numeric(vec)
        return(max(vec))
    }
    scores = apply(scores, 1, .get_max)
    output = cbind(output, scores)
    col_names = c('cell_id', "predicted_label", "score")
} else{
    col_names = c('cell_id', "predicted_label")
}

colnames(output) = col_names
# get rid of the goddamn dots
output[, "predicted_label"] = sapply(output[, "predicted_label"], function(x) x = gsub(pattern = '.', replacement = ' ', x, fixed = TRUE))
# add metadata if classifier is specified 
append = FALSE
if(!is.na(opt$classifier)){
    append = TRUE
    cl = readRDS(opt$classifier)
    dataset = attributes(cl)$dataset
    system(paste("echo '# tool scpred' >", opt$output_table))
    system(paste("echo '# dataset'", dataset, ">>", opt$output_table))
}
write.table(output, file = opt$output_table, sep="\t", row.names=FALSE, append=append)

==> scpred-cli-0.1.0-1.tar.bz2: bin/scpred_get_std_output.R <==
#!/usr/bin/env Rscript
suppressPackageStartupMessages(require(optparse))
suppressPackageStartupMessages(require(workflowscriptscommon))

### create final workflow output in standard format
option_list = list(
    make_option(
        c("-i", "--predictions-object"),
        action = 'store',
        default = NA,
        type = 'character',
        help = 'Path to the Seurat predictions object in .rds format'
    ),
    make_option(
        c("-s", "--get-scores"),
        action = 'store_true',
        default = TRUE,
        type = 'logical',
        help = 'Should score column be added? Default: TRUE'
    ),
    make_option(
        c("-k", "--classifier"),
        action = 'store',
        default = NA,
        type = 'character',
        help = 'Path to the classifier object in .rds format (Optional; required to add dataset of origin to output table)'
    ),
    make_option(
        c("-o", "--output-table"),
        action = 'store',
        default = NA,
        type = 'character',
        help = 'Path to the final output file in text format'
    )
)

opt = wsc_parse_args(option_list, mandatory = c("predictions_object", "output_table"))
suppressPackageStartupMessages(require(Seurat))
suppressPackageStartupMessages(require(scPred))

data = readRDS(opt$predictions_object)
pred_labels = data$scpred_prediction
barcodes = names(pred_labels)

output = cbind(barcodes, unname(pred_labels))
if(opt$get_scores){
    scores = unname(data$scpred_max)
    output = cbind(output, scores)
    col_names = c('cell_id', "predicted_label", "score")
} else{
    col_names = c('cell_id', "predicted_label")
}
colnames(output) = col_names

# get rid of the goddamn dots
output[, "predicted_label"] = sapply(output[, "predicted_label"], function(x) x = gsub(pattern = '.', replacement = ' ', x, fixed = TRUE))
# add metadata if classifier is specified 
append = FALSE
if(!is.na(opt$classifier)){
    append = TRUE
    cl = readRDS(opt$classifier)
    dataset = attributes(cl)$dataset
    system(paste("echo '# tool scpred' >", opt$output_table))
    system(paste("echo '# dataset'", dataset, ">>", opt$output_table))
}
write.table(output, file = opt$output_table, sep="\t", row.names=FALSE, append=append)
